Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIlya Zverev <zverik@textual.ru>2017-03-20 15:51:59 +0300
committerSergey Yershov <syershov@maps.me>2017-03-20 16:36:09 +0300
commit42ceabc905dae250643079ad8b3ce6e35eea06ca (patch)
treed85b7c099786021e620e082f36d928bc638b3bde
parent0010540f224a815632a991b58c6165e75603fbf6 (diff)
[build] Fix cmake in build_omim and error detection in booking_hotels
-rwxr-xr-xtools/python/booking_hotels.py2
-rwxr-xr-xtools/unix/build_omim.sh8
2 files changed, 5 insertions, 5 deletions
diff --git a/tools/python/booking_hotels.py b/tools/python/booking_hotels.py
index ef58443180..20950706af 100755
--- a/tools/python/booking_hotels.py
+++ b/tools/python/booking_hotels.py
@@ -60,7 +60,7 @@ class BookingApi:
stream = urllib2.urlopen(request)
payload = stream.read()
data = json.loads(payload)
- if isinstance(data, dict) and 'ruid' in data:
+ if isinstance(data, dict) and 'message' in data and 'code' in data:
logging.error('Api call failed with error: {0} Code: {1}'.format(data['message'], data['code']))
return None
return data
diff --git a/tools/unix/build_omim.sh b/tools/unix/build_omim.sh
index 1305c38bae..6282a34a51 100755
--- a/tools/unix/build_omim.sh
+++ b/tools/unix/build_omim.sh
@@ -57,9 +57,9 @@ fi
# Find qmake, prefer qmake-qt5
source "$OMIM_PATH/tools/autobuild/detect_qmake.sh"
# Find cmake, prefer cmake28
if [ ! -x "${CMAKE-}" ]; then
- CMAKE=cmake28
+ CMAKE=cmake3
if ! hash "$CMAKE" 2>/dev/null; then
CMAKE=cmake
fi
@@ -113,11 +113,11 @@ build_conf_osrm()
export BOOST_INCLUDEDIR="$BOOST_PATH/include"
cd "$DIRNAME"
- if [[ -z ${CMAKE_OMIM+x} ]]; then
+ if [[ -n "${USE_CMAKE-}" ]]; then
DIRNAME="$DIRNAME/out/$CONF"
mkdir -p "$DIRNAME"
cd "$DIRNAME"
- cmake "$OMIM_PATH"
+ "$CMAKE" "$OMIM_PATH"
make routing routing_common indexer geometry coding base jansson -j $PROCESSES
else
"$QMAKE" "$OMIM_PATH/omim.pro" ${SPEC:+-spec $SPEC} "CONFIG+=$CONF osrm no-tests" ${CONFIG+"CONFIG*=$CONFIG"}
@@ -57,9 +57,9 @@ fi
# Find qmake, prefer qmake-qt5
source "$OMIM_PATH/tools/autobuild/detect_qmake.sh"
-# Find cmake, prefer cmake28
+# Find cmake, prefer cmake3
if [ ! -x "${CMAKE-}" ]; then